/*
 * Thanks to Scot Laird, Russell Nelson, and others..
 *
 * Copyright (C) 1996 by Thomas Davis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL SCOTT LAIRD BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

/*
 * Before making any major changes, please look at the assembler output.
 * You may be suprised at what you get..
 * ie:
 * gcc -O6 -fno-strength-reduce -S bi6bit.c
 *
 */

#define __KERNEL__
#define MODULE

#include <linux/kernel.h>
#include <asm/io.h>

#include "quickcam.h"
#include "qcam-kernel.h"

int waitfor_bi(struct quickcam *qc)
{
	unsigned char status1, status2;

	if (qc->debug > 1) 
		printk("waiting for camera to become ready..\n");

	outb(0x26, qc->port + 2);

	do {
		status1 = inb(qc->port + 1);
	} while (!(status1 & 0x08));

	outb(0x2f, qc->port+2);

	do {
		status2 = inb(qc->port+1);
	} while (status2 & 0x08);

	if (qc->debug > 1) {
		printk("status1 = 0x%02x ", status1);
		printk("status2 = 0x%02x ", status2);
		printk("status = 0x%02x\n",((status1 & 0xF0) | ( status2 >> 4 )));
	}

	return ((status1 & 0xF0 ) | ( status2 >> 4 ));

}

void bi_6bit(struct quickcam *qc)
{
	unsigned int word1;
	unsigned char *tmp = qc->buffer;

	if (qc->debug > 1)
		printk("starting bi_6bit scan..\n");

	outb(0x26, qc->port+2);

	while (tmp < qc->buffer + (qc->xsize * (qc->ysize))) {
		do {
			word1 = inw(qc->port);
		} while (!(word1 & 0x01));

		outb(0x2f, qc->port+2);

		*tmp++ = 63 - ((word1 >> 1 ) & 0x3f);
		*tmp++ = 63 - (((word1 >> 10) | ((word1 >> 7) & 0x01)) & 0x3f);

		do {
			word1 = inw(qc->port);
		} while (word1 & 0x01);

		outb(0x26, qc->port+2);

		*tmp++ = 63 - ((word1 >> 1 ) & 0x3f);
		*tmp++ = 63 - (((word1 >> 10) | ((word1 >> 7) & 0x01)) & 0x3f);
	}

	if (qc->debug > 1)
		printk("bi_6bit: scan done.\n");

	outb(0x26, qc->port + 2);

	do {
		word1 = inw(qc->port);
	} while (!(word1 & 0x1));

	if (qc->debug > 1)
		printk("bi_6bit: handshake done.\n");

	outb(0x0f, qc->port + 2);

	if (qc->debug > 1)
		printk("bi_6bit done.\n");

}
