/*
 * Thanks to Scot Laird, Russell Nelson, and others..
 *
 * Copyright (C) 1996 by Thomas Davis
 *
 * Copyright (C) 1996 by Scott Laird
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL SCOTT LAIRD BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */


#ifndef _QUICKCAM_H

#define _QUICKCAM_H 1

/*
 * These are the ioctls..
 */

#define QC_SET			0x0001
#define QC_GET			0x0002
#define QC_SET_BRIGHTNESS	0x0003
#define QC_GET_BRIGHTNESS	0x0004
#define QC_SET_CONTRAST		0x0005
#define QC_GET_CONTRAST		0x0006
#define QC_SET_WHITE_BALANCE	0x0007
#define QC_GET_WHITE_BALANCE	0x0008

/*
 * These are the zoom modes..
 */

#define QC_NO_ZOOM		0x0000
#define QC_ZOOM_15x		0x0001
#define QC_ZOOM_2x		0x0002

/*
 * and the port directions...
 */

#define QC_BIDIR		0x0000
#define QC_UNIDIR		0x0001
#define QC_SERIAL		0x0002

/*
 * frame buffer size..
 */

#define FRAME_BUFFER_SIZE 320*240

/*
 * This is the structure to pass into the ioctl.  Has either all of
 * the settable fields, or the readable fields.
 *
 * To set brightness, contrast, or whitebalance, simply pass in the
 * address of a int.
 */	

struct qcam {
	int xsize;			/* x direction (horizontal) size */
	int ysize;			/* y direction (vertical) size */
	int bpp;			/* 4 or 6 bits per pixel */
	int mode;			/* bi or uni directional mode */
	int zoom;			/* zoom mode, 1x, 1.5x, or 2x */
	int debug;			/* debug mode. 0 = very quiet. */
	int framecount;			/* frame count. */
	unsigned char brightness;
	unsigned char whitebalance;
	unsigned char contrast;
	unsigned char status;
};

#endif
